﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace _3台同時再生__client_
{
	public partial class MainForm : Form
	{
		private Microsoft.DirectX.AudioVideoPlayback.Video media;
		private System.Drawing.Image red;
		private System.Drawing.Image yellow;
		private System.Drawing.Image green;
		private string server1Name;
		private string server2Name;
		private int server1Port;
		private int server2Port;

		private System.Net.Sockets.TcpClient tcp1;
		private System.Net.Sockets.TcpClient tcp2;

		public MainForm()
		{
			InitializeComponent();

			red = System.Drawing.Image.FromFile("red.gif");
			yellow = System.Drawing.Image.FromFile("yellow.gif");
			green = System.Drawing.Image.FromFile("green.gif");

			server1Button.Image = red;
			server2Button.Image = red;

			playButton.Image = System.Drawing.Image.FromFile("play.gif");
			stopButton.Image = System.Drawing.Image.FromFile("stop.gif");
		}

		private void loop1()
		{
			try {
				tcp1 = new System.Net.Sockets.TcpClient();
				
				tcp1.Connect(server1Name, server1Port);
				server1Button.Image = yellow;

				System.IO.StreamReader reader = new System.IO.StreamReader(tcp1.GetStream());

				string cmd = reader.ReadLine();
				if (cmd == "already.") {
					server1Button.Image = green;
				}
			}
			catch (Exception exp) {
				MessageBox.Show(exp.Message);
			}
		}

		private void loop2()
		{
			try {
				tcp2 = new System.Net.Sockets.TcpClient();

				tcp2.Connect(server2Name, server2Port);
				server2Button.Image = yellow;

				System.IO.StreamReader reader = new System.IO.StreamReader(tcp2.GetStream());

				string cmd = reader.ReadLine();
				if (cmd == "already.") {
					server2Button.Image = green;
				}
			}
			catch (Exception exp) {
				MessageBox.Show(exp.Message);
			}
		}

		private void Form1_DragEnter(object sender, DragEventArgs e)
		{
			// マウスカーソルの変更
			e.Effect =
				e.Data.GetDataPresent(DataFormats.FileDrop) ?
				DragDropEffects.Move :
				DragDropEffects.None;
		}

		private void Form1_DragDrop(object sender, DragEventArgs e)
		{
			// ドラッグされたファイルのファイル名
			string[] fileName =
				e.Data.GetData(DataFormats.FileDrop) as string[];

			if (media == null) {
				media = new Microsoft.DirectX.AudioVideoPlayback.Video(fileName[0]);
				media.Owner = this.panel1;
				media.Play();
				media.Pause();
			}
			else {
				media.Dispose();
				media = new Microsoft.DirectX.AudioVideoPlayback.Video(fileName[0]);
				media.Owner = this.panel1;
				media.Play();
				media.Pause();
			}
		}

		private void server1Button_Click(object sender, EventArgs e)
		{
			if (tcp1 != null) return;

			DestinationInformationForm form = new DestinationInformationForm();

			if (form.ShowDialog() == DialogResult.Cancel) return;

			server1Name = form.addressTextBox.Text;
			server1Port = int.Parse(form.portTextBox.Text);

			// TCP接続＆コマンド受信用スレッド
			System.Threading.Thread t =
				new System.Threading.Thread(
					new System.Threading.ThreadStart(loop1));
			t.IsBackground = true;
			t.Start();
		}

		private void server2Button_Click(object sender, EventArgs e)
		{
			if (tcp2 != null) return;

			DestinationInformationForm form = new DestinationInformationForm();

			if (form.ShowDialog() == DialogResult.Cancel) return;

			server2Name = form.addressTextBox.Text;
			server2Port = int.Parse(form.portTextBox.Text);

			// TCP接続＆コマンド受信用スレッド
			System.Threading.Thread t =
				new System.Threading.Thread(
					new System.Threading.ThreadStart(loop2));
			t.IsBackground = true;
			t.Start();
		}

		private void Form1_KeyDown(object sender, KeyEventArgs e)
		{
			if (media == null) return;

			if (e.Alt && e.KeyCode == Keys.Enter) {
				media.Fullscreen = !media.Fullscreen;
			}
		}

		private void panel1_PreviewKeyDown(object sender, PreviewKeyDownEventArgs e)
		{
			if (media == null) return;

			if (e.Alt && e.KeyCode == Keys.Enter) {
				media.Fullscreen = !media.Fullscreen;
			}
		}

		private void playButton_Click(object sender, EventArgs e)
		{
			if (media == null) {
				MessageBox.Show("メディアファイルが指定されていません。");
				return;
			}

			if (server1Button.Image != green) {
				MessageBox.Show("server1の準備が整っていません。");
				return;
			}

			if (server2Button.Image != green) {
				MessageBox.Show("server2の準備が整っていません。");
				return;
			}

			// 既に再生していたらリターン
			if (media.Playing) {
				return;
			}

			System.IO.StreamWriter writer1 = new System.IO.StreamWriter(tcp1.GetStream());
			System.IO.StreamWriter writer2 = new System.IO.StreamWriter(tcp2.GetStream());

			// 再生処理
			media.Play();
			
			writer1.WriteLine("play.");
			writer1.Flush();

			writer2.WriteLine("play.");
			writer2.Flush();
		}

		private void stopButton_Click(object sender, EventArgs e)
		{
			if (media == null) {
				MessageBox.Show("メディアファイルが指定されていません。");
				return;
			}

			if (server1Button.Image != green) {
				MessageBox.Show("server1の準備が整っていません。");
				return;
			}

			if (server2Button.Image != green) {
				MessageBox.Show("server2の準備が整っていません。");
				return;
			}

			// 既に停止していたらリターン
			if (media.Stopped) {
				return;
			}

			System.IO.StreamWriter writer1 = new System.IO.StreamWriter(tcp1.GetStream());
			System.IO.StreamWriter writer2 = new System.IO.StreamWriter(tcp2.GetStream());

			// 停止処理
			media.Stop();

			writer1.WriteLine("stop.");
			writer1.Flush();

			writer2.WriteLine("stop.");
			writer2.Flush();
		}
	}
}
